@@ -1,7 +1,7 @@
 // -*- mode: C++; c-file-style: "cc-mode" -*-
 //*************************************************************************
 //
-// Copyright 2003-2018 by Wilson Snyder. This program is free software; you can
+// Copyright 2003-2019 by Wilson Snyder. This program is free software; you can
 // redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License.
 // Version 2.0.
@@ -26,31 +26,30 @@
 
 
 #ifndef _VERILATED_H_
-#define _VERILATED_H_ 1 ///< Header Guard
+#define _VERILATED_H_ 1  ///< Header Guard
 
-#include "verilated_config.h"
 #include "verilatedos.h"
 
 #include <cassert>
+#include <cmath>
 #include <cstdarg>
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
-#include <cmath>
+// <iostream> avoided to reduce compile time
+// <map> avoided and instead in verilated_heavy.h to reduce compile time
+// <string> avoided and instead in verilated_heavy.h to reduce compile time
 #ifdef VL_THREADED
 # include <atomic>
 # include <mutex>
 # include <thread>
 #endif
-// <iostream> avoided to reduce compile time
-// <map> avoided and instead in verilated_heavy.h to reduce compile time
-// <string> avoided and instead in verilated_heavy.h to reduce compile time
 
 //=============================================================================
 // Switches
 
-#if VM_TRACE		// Verilator tracing requested
-# define WAVES 1	// Set backward compatibility flag
+#if VM_TRACE  // Verilator tracing requested
+# define WAVES 1  // Set backward compatibility flag
 #endif
 
 //=========================================================================
@@ -79,8 +78,8 @@ class VerilatedVar;
 class VerilatedVarNameMap;
 class VerilatedVcd;
 class VerilatedVcdC;
-class VerilatedLxt2;
-class VerilatedLxt2C;
+class VerilatedFst;
+class VerilatedFstC;
 
 enum VerilatedVarType {
     VLVT_UNKNOWN=0,
@@ -94,15 +93,16 @@ enum VerilatedVarType {
 };
 
 enum VerilatedVarFlags {
-    VLVD_IN=1,		// == vpiInput
-    VLVD_OUT=2,		// == vpiOutput
-    VLVD_INOUT=3,	// == vpiInOut
-    VLVD_NODIR=5,	// == vpiNoDirection
-    VLVF_MASK_DIR=7,	// Bit mask for above directions
+    VLVD_0 = 0,         // None
+    VLVD_IN = 1,	// == vpiInput
+    VLVD_OUT = 2,	// == vpiOutput
+    VLVD_INOUT = 3,	// == vpiInOut
+    VLVD_NODIR = 5,	// == vpiNoDirection
+    VLVF_MASK_DIR = 7,	// Bit mask for above directions
     // Flags
-    VLVF_PUB_RD=(1<<8),	// Public readable
-    VLVF_PUB_RW=(1<<9),  // Public writable
-    VLVF_DPI_CLAY=(1<<10)  // DPI compatible C standard layout
+    VLVF_PUB_RD = (1<<8),  // Public readable
+    VLVF_PUB_RW = (1<<9),  // Public writable
+    VLVF_DPI_CLAY = (1<<10)  // DPI compatible C standard layout
 };
 
 //=========================================================================
@@ -156,7 +156,7 @@ class VL_SCOPED_CAPABILITY VerilatedLockGuard {
     }
 };
 
-#else // !VL_THREADED
+#else  // !VL_THREADED
 
 /// Empty non-threaded mutex to avoid #ifdefs in consuming code
 class VerilatedMutex {
@@ -173,7 +173,7 @@ public:
     ~VerilatedLockGuard() {}
 };
 
-#endif // VL_THREADED
+#endif  // VL_THREADED
 
 /// Remember the calling thread at construction time, and make sure later calls use same thread
 class VerilatedAssertOneThread {
@@ -194,7 +194,7 @@ public:
         }
     }
     static void fatal_different() VL_MT_SAFE;
-#else // !VL_THREADED || !VL_DEBUG
+#else  // !VL_THREADED || !VL_DEBUG
 public:
     void check() {}
 #endif
@@ -206,11 +206,11 @@ public:
 class VerilatedModule {
     VL_UNCOPYABLE(VerilatedModule);
 private:
-    const char*		m_namep;	///< Module name
+    const char* m_namep;  ///< Module name
 public:
-    explicit VerilatedModule(const char* namep);	///< Create module with given hierarchy name
+    explicit VerilatedModule(const char* namep);  ///< Create module with given hierarchy name
     ~VerilatedModule();
-    const char* name() const { return m_namep; }	///< Return name of module
+    const char* name() const { return m_namep; }  ///< Return name of module
 };
 
 //=========================================================================
@@ -334,9 +334,9 @@ class Verilated {
 
     static VerilatedVoidCb  s_flushCb;		///< Flush callback function
 
-    static struct Serialized {   // All these members serialized/deserialized
-	// Fast path
-	int		s_debug;		///< See accessors... only when VL_DEBUG set
+    static struct Serialized {  // All these members serialized/deserialized
+        // Fast path
+        int             s_debug;                ///< See accessors... only when VL_DEBUG set
 	bool		s_calcUnusedSigs;	///< Waves file on, need all signals calculated
 	bool		s_gotFinish;		///< A $finish statement executed
 	bool		s_assertOn;		///< Assertions are enabled
@@ -445,8 +445,8 @@ public:
     static const char* commandArgsPlusMatch(const char* prefixp) VL_MT_SAFE;
 
     /// Produce name & version for (at least) VPI
-    static const char* productName() VL_PURE { return VERILATOR_PRODUCT; }
-    static const char* productVersion() VL_PURE { return VERILATOR_VERSION; }
+    static const char* productName() VL_PURE;
+    static const char* productVersion() VL_PURE;
 
     /// Convenience OS utilities
     static void mkdir(const char* dirname) VL_MT_UNSAFE;
@@ -468,7 +468,7 @@ public:
 public:
     // METHODS - INTERNAL USE ONLY (but public due to what uses it)
     // Internal: Create a new module name by concatenating two strings
-    static const char* catName(const char* n1, const char* n2); // Returns static data
+    static const char* catName(const char* n1, const char* n2);  // Returns static data
 
     // Internal: Throw signal assertion
     static void overWidthError(const char* signame) VL_MT_SAFE;
@@ -489,7 +489,7 @@ public:
     static int exportFuncNum(const char* namep) VL_MT_SAFE;
 
     static size_t serializedSize() VL_PURE { return sizeof(s_s); }
-    static void* serializedPtr() VL_MT_UNSAFE { return &s_s; } // Unsafe, for Serialize only
+    static void* serializedPtr() VL_MT_UNSAFE { return &s_s; }  // Unsafe, for Serialize only
 #ifdef VL_THREADED
     /// Set the mtaskId, called when an mtask starts
     static void mtaskId(vluint32_t id) VL_MT_SAFE { t_s.t_mtaskId = id; }
@@ -560,15 +560,15 @@ extern void VL_PRINTF_MT(const char* formatp, ...) VL_ATTR_PRINTF(1) VL_MT_SAFE;
 /// Print a debug message from internals with standard prefix, with printf style format
 extern void VL_DBG_MSGF(const char* formatp, ...) VL_ATTR_PRINTF(1) VL_MT_SAFE;
 
-extern IData  VL_RANDOM_I(int obits);	///< Randomize a signal
-extern QData  VL_RANDOM_Q(int obits);	///< Randomize a signal
-extern WDataOutP VL_RANDOM_W(int obits, WDataOutP outwp);	///< Randomize a signal
+extern IData  VL_RANDOM_I(int obits);  ///< Randomize a signal
+extern QData  VL_RANDOM_Q(int obits);  ///< Randomize a signal
+extern WDataOutP VL_RANDOM_W(int obits, WDataOutP outwp);  ///< Randomize a signal
 
 /// Init time only, so slow is fine
-extern IData  VL_RAND_RESET_I(int obits);	///< Random reset a signal
-extern QData  VL_RAND_RESET_Q(int obits);	///< Random reset a signal
-extern WDataOutP VL_RAND_RESET_W(int obits, WDataOutP outwp);	///< Random reset a signal
-extern WDataOutP VL_ZERO_RESET_W(int obits, WDataOutP outwp);	///< Zero reset a signal (slow - else use VL_ZERO_W)
+extern IData  VL_RAND_RESET_I(int obits);  ///< Random reset a signal
+extern QData  VL_RAND_RESET_Q(int obits);  ///< Random reset a signal
+extern WDataOutP VL_RAND_RESET_W(int obits, WDataOutP outwp);  ///< Random reset a signal
+extern WDataOutP VL_ZERO_RESET_W(int obits, WDataOutP outwp);  ///< Zero reset a signal (slow - else use VL_ZERO_W)
 
 #if VL_THREADED
 /// Return high-precision counter for profiling, or 0x0 if not available
@@ -581,29 +581,29 @@ extern WDataOutP _vl_moddiv_w(int lbits, WDataOutP owp, WDataInP lwp, WDataInP r
 /// File I/O
 extern IData VL_FGETS_IXI(int obits, void* destp, IData fpi);
 
-extern IData VL_FOPEN_S(const char* filenamep, const char* mode);
-extern IData VL_FOPEN_WI(int fnwords, WDataInP ofilename, IData mode);
-extern IData VL_FOPEN_QI(QData ofilename, IData mode);
-inline IData VL_FOPEN_II(IData ofilename, IData mode) VL_MT_SAFE {
-    return VL_FOPEN_QI(ofilename,mode); }
+extern IData VL_FOPEN_S(const char* filenamep, const char* modep);
+extern IData VL_FOPEN_WI(int fnwords, WDataInP filenamep, IData mode);
+extern IData VL_FOPEN_QI(QData filename, IData mode);
+inline IData VL_FOPEN_II(IData filename, IData mode) VL_MT_SAFE {
+    return VL_FOPEN_QI(filename,mode); }
 
 extern void VL_FCLOSE_I(IData fdi);
 
 extern void VL_READMEM_W(bool hex, int width, int depth, int array_lsb, int fnwords,
-			 WDataInP ofilename, void* memp, IData start, IData end);
+                         WDataInP filenamep, void* memp, IData start, IData end);
 extern void VL_READMEM_Q(bool hex, int width, int depth, int array_lsb, int fnwords,
-			 QData ofilename,    void* memp, IData start, IData end);
+                         QData filename,     void* memp, IData start, IData end);
 inline void VL_READMEM_I(bool hex, int width, int depth, int array_lsb, int fnwords,
-			 IData ofilename,    void* memp, IData start, IData end) VL_MT_SAFE {
-    VL_READMEM_Q(hex, width,depth,array_lsb,fnwords, ofilename,memp,start,end); }
+                         IData filename,     void* memp, IData start, IData end) VL_MT_SAFE {
+    VL_READMEM_Q(hex, width,depth,array_lsb,fnwords, filename,memp,start,end); }
 
 extern void VL_WRITEMEM_W(bool hex, int width, int depth, int array_lsb, int fnwords,
-                          WDataInP ofilename, const void* memp, IData start, IData end);
+                          WDataInP filenamep, const void* memp, IData start, IData end);
 extern void VL_WRITEMEM_Q(bool hex, int width, int depth, int array_lsb, int fnwords,
-                          QData ofilename,    const void* memp, IData start, IData end);
+                          QData filename,     const void* memp, IData start, IData end);
 inline void VL_WRITEMEM_I(bool hex, int width, int depth, int array_lsb, int fnwords,
-                          IData ofilename,    const void* memp, IData start, IData end) VL_MT_SAFE {
-    VL_WRITEMEM_Q(hex, width,depth,array_lsb,fnwords, ofilename,memp,start,end); }
+                          IData filename,     const void* memp, IData start, IData end) VL_MT_SAFE {
+    VL_WRITEMEM_Q(hex, width,depth,array_lsb,fnwords, filename,memp,start,end); }
 
 extern void VL_WRITEF(const char* formatp, ...);
 extern void VL_FWRITEF(IData fpi, const char* formatp, ...);
@@ -619,7 +619,7 @@ extern void VL_SFORMAT_X(int obits, IData& destr, const char* formatp, ...);
 extern void VL_SFORMAT_X(int obits, QData& destr, const char* formatp, ...);
 extern void VL_SFORMAT_X(int obits, void* destp, const char* formatp, ...);
 
-extern IData VL_SYSTEM_IW(int lhsnwords, WDataInP lhs);
+extern IData VL_SYSTEM_IW(int lhswords, WDataInP lhsp);
 extern IData VL_SYSTEM_IQ(QData lhs);
 inline IData VL_SYSTEM_II(IData lhs) VL_MT_SAFE { return VL_SYSTEM_IQ(lhs); }
 
@@ -630,24 +630,24 @@ extern const char* vl_mc_scan_plusargs(const char* prefixp);  // PLIish
 // Base macros
 
 /// Return true if data[bit] set; not 0/1 return, but 0/non-zero return.
-#define VL_BITISSET_I(data,bit) (data & (VL_UL(1)<<VL_BITBIT_I(bit)))
-#define VL_BITISSET_Q(data,bit) (data & (VL_ULL(1)<<VL_BITBIT_Q(bit)))
-#define VL_BITISSET_W(data,bit) (data[VL_BITWORD_I(bit)] & (VL_UL(1)<<VL_BITBIT_I(bit)))
+#define VL_BITISSET_I(data,bit) ((data) & (VL_UL(1) << VL_BITBIT_I(bit)))
+#define VL_BITISSET_Q(data,bit) ((data) & (VL_ULL(1) << VL_BITBIT_Q(bit)))
+#define VL_BITISSET_W(data,bit) ((data)[VL_BITWORD_I(bit)] & (VL_UL(1) << VL_BITBIT_I(bit)))
 #define VL_BITISSETLIMIT_W(data,width,bit) \
-    (((bit)<(width)) && data[VL_BITWORD_I(bit)] & (VL_UL(1)<<VL_BITBIT_I(bit)))
+    (((bit)<(width)) && (data)[VL_BITWORD_I(bit)] & (VL_UL(1) << VL_BITBIT_I(bit)))
 
 /// Shift appropriate word by bit. Does not account for wrapping between two words
-#define VL_BITRSHIFT_W(data,bit) (data[VL_BITWORD_I(bit)] >> VL_BITBIT_I(bit))
+#define VL_BITRSHIFT_W(data,bit) ((data)[VL_BITWORD_I(bit)] >> VL_BITBIT_I(bit))
 
 /// Create two 32-bit words from quadword
 /// WData is always at least 2 words; does not clean upper bits
-#define VL_SET_WQ(owp,data)     { owp[0]=static_cast<IData>(data); \
-        owp[1]=static_cast<IData>((data)>>VL_WORDSIZE); }
-#define VL_SET_WI(owp,data)	{ owp[0]=static_cast<IData>(data); owp[1]=0; }
+#define VL_SET_WQ(owp,data) { (owp)[0] = static_cast<IData>(data);  \
+        (owp)[1] = static_cast<IData>((data)>>VL_WORDSIZE); }
+#define VL_SET_WI(owp,data) { (owp)[0] = static_cast<IData>(data); (owp)[1] = 0; }
 #define VL_SET_QW(lwp) \
-    ( (static_cast<QData>(lwp[0])) \
-      | (static_cast<QData>(lwp[1])<<(static_cast<QData>(VL_WORDSIZE)) ))
-#define _VL_SET_QII(ld,rd)      ( (static_cast<QData>(ld)<<VL_ULL(32)) | static_cast<QData>(rd) )
+    ( (static_cast<QData>((lwp)[0]))                                    \
+      | (static_cast<QData>((lwp)[1]) << (static_cast<QData>(VL_WORDSIZE)) ))
+#define _VL_SET_QII(ld,rd) ((static_cast<QData>(ld)<<VL_ULL(32)) | static_cast<QData>(rd))
 
 /// Return FILE* from IData
 extern FILE*  VL_CVT_I_FP(IData lhs);
@@ -696,7 +696,7 @@ extern void _VL_DEBUG_PRINT_W(int lbits, WDataInP iwp);
 // Pli macros
 
 #ifndef VL_TIME_PRECISION
-# define VL_TIME_PRECISION -12	///< Timescale units only for for VPI return - picoseconds
+# define VL_TIME_PRECISION (-12)  ///< Timescale units only for for VPI return - picoseconds
 #endif
 #ifndef VL_TIME_MULTIPLIER
 # define VL_TIME_MULTIPLIER 1
@@ -826,31 +826,32 @@ static inline void VL_ASSIGNBIT_WO(int, int bit, WDataOutP owp, IData) VL_MT_SAF
 #define VL_ASSIGN_ISI(obits,vvar,svar) { (vvar) = VL_CLEAN_II((obits),(obits),(svar).read()); }
 #define VL_ASSIGN_QSQ(obits,vvar,svar) { (vvar) = VL_CLEAN_QQ((obits),(obits),(svar).read()); }
 
-#define VL_ASSIGN_ISW(obits,od,svar) { \
-    od = (svar.read().get_word(0)) & VL_MASK_I(obits); \
-}
-#define VL_ASSIGN_QSW(obits,od,svar) { \
-    od = ((static_cast<QData>(svar.read().get_word(1)))<<VL_WORDSIZE | svar.read().get_word(0)) \
-         & VL_MASK_Q(obits); \
-}
-#define VL_ASSIGN_WSW(obits,owp,svar) { \
-    int words = VL_WORDS_I(obits); \
-    for (int i=0; i < words; ++i) owp[i] = svar.read().get_word(i); \
-    owp[words-1] &= VL_MASK_I(obits); \
-}
+#define VL_ASSIGN_ISW(obits,od,svar) {                          \
+        (od) = ((svar).read().get_word(0)) & VL_MASK_I(obits);  \
+    }
+#define VL_ASSIGN_QSW(obits,od,svar) {                                  \
+        (od) = ((static_cast<QData>((svar).read().get_word(1)))<<VL_WORDSIZE \
+                | (svar).read().get_word(0))                            \
+            & VL_MASK_Q(obits);                                         \
+    }
+#define VL_ASSIGN_WSW(obits,owp,svar) {                                 \
+        int words = VL_WORDS_I(obits);                                  \
+        for (int i=0; i < words; ++i) (owp)[i] = (svar).read().get_word(i); \
+        (owp)[words-1] &= VL_MASK_I(obits);                             \
+    }
 
 #define VL_ASSIGN_ISU(obits,vvar,svar) { (vvar) = VL_CLEAN_II((obits),(obits),(svar).read().to_uint()); }
 #define VL_ASSIGN_QSU(obits,vvar,svar) { (vvar) = VL_CLEAN_QQ((obits),(obits),(svar).read().to_uint64()); }
-#define VL_ASSIGN_WSB(obits,owp,svar) {                       \
-    int words = VL_WORDS_I(obits);                            \
-    sc_biguint<obits> _butemp = (svar).read();                \
-    for (int i=0; i < words; ++i) {                           \
-        int msb = ((i+1)*VL_WORDSIZE) - 1;                    \
-        msb = (msb >= obits) ? (obits-1) : msb;               \
-        owp[i] = _butemp.range(msb,i*VL_WORDSIZE).to_uint();  \
-    }                                                         \
-    owp[words-1] &= VL_MASK_I(obits);                         \
-}
+#define VL_ASSIGN_WSB(obits,owp,svar) {                                 \
+        int words = VL_WORDS_I(obits);                                  \
+        sc_biguint<(obits)> _butemp = (svar).read();                    \
+        for (int i=0; i < words; ++i) {                                 \
+            int msb = ((i+1)*VL_WORDSIZE) - 1;                          \
+            msb = (msb >= (obits)) ? ((obits)-1) : msb;                 \
+            (owp)[i] = _butemp.range(msb,i*VL_WORDSIZE).to_uint();      \
+        }                                                               \
+        (owp)[words-1] &= VL_MASK_I(obits);                             \
+    }
 
 // Copying verilog format from systemc integers and bit vectors.
 // Set a SystemC variable
@@ -858,36 +859,36 @@ static inline void VL_ASSIGNBIT_WO(int, int bit, WDataOutP owp, IData) VL_MT_SAF
 #define VL_ASSIGN_SII(obits,svar,vvar) { (svar).write(vvar); }
 #define VL_ASSIGN_SQQ(obits,svar,vvar) { (svar).write(vvar); }
 
-#define VL_ASSIGN_SWI(obits,svar,rd) { \
-    sc_bv<obits> _bvtemp; \
-    _bvtemp.set_word(0,(rd));			\
-    svar.write(_bvtemp); \
-}
-#define VL_ASSIGN_SWQ(obits,svar,rd) { \
-    sc_bv<obits> _bvtemp; \
-    _bvtemp.set_word(0, static_cast<IData>(rd));	 \
-    _bvtemp.set_word(1, static_cast<IData>((rd)>>VL_WORDSIZE));	\
-    svar.write(_bvtemp); \
-}
-#define VL_ASSIGN_SWW(obits,svar,rwp) { \
-    sc_bv<obits> _bvtemp; \
-    for (int i=0; i < VL_WORDS_I(obits); ++i) _bvtemp.set_word(i,rwp[i]); \
-    svar.write(_bvtemp); \
-}
+#define VL_ASSIGN_SWI(obits,svar,rd) {          \
+        sc_bv<(obits)> _bvtemp;                 \
+        _bvtemp.set_word(0, (rd));              \
+        (svar).write(_bvtemp);                  \
+    }
+#define VL_ASSIGN_SWQ(obits,svar,rd) {                                  \
+        sc_bv<(obits)> _bvtemp;                                         \
+        _bvtemp.set_word(0, static_cast<IData>(rd));                    \
+        _bvtemp.set_word(1, static_cast<IData>((rd)>>VL_WORDSIZE));     \
+        (svar).write(_bvtemp);                                          \
+    }
+#define VL_ASSIGN_SWW(obits,svar,rwp) {                                 \
+        sc_bv<(obits)> _bvtemp;                                         \
+        for (int i=0; i < VL_WORDS_I(obits); ++i) _bvtemp.set_word(i, (rwp)[i]); \
+        (svar).write(_bvtemp);                                          \
+    }
 
 #define VL_ASSIGN_SUI(obits,svar,rd) { (svar).write(rd); }
 #define VL_ASSIGN_SUQ(obits,svar,rd) { (svar).write(rd); }
 #define VL_ASSIGN_SBI(obits,svar,rd) { (svar).write(rd); }
 #define VL_ASSIGN_SBQ(obits,svar,rd) { (svar).write(rd); }
-#define VL_ASSIGN_SBW(obits,svar,rwp) {             \
-    sc_biguint<obits> _butemp;                      \
-    for (int i=0; i < VL_WORDS_I(obits); ++i) {     \
-        int msb = ((i+1)*VL_WORDSIZE) - 1;          \
-        msb = (msb >= obits) ? (obits-1) : msb;     \
-        _butemp.range(msb,i*VL_WORDSIZE) = rwp[i];  \
-    }                                               \
-    svar.write(_butemp);                            \
-}
+#define VL_ASSIGN_SBW(obits,svar,rwp) {                         \
+        sc_biguint<(obits)> _butemp;                            \
+        for (int i=0; i < VL_WORDS_I(obits); ++i) {             \
+            int msb = ((i+1)*VL_WORDSIZE) - 1;                  \
+            msb = (msb >= (obits)) ? ((obits)-1) : msb;         \
+            _butemp.range(msb, i*VL_WORDSIZE) = (rwp)[i];       \
+        }                                                       \
+        (svar).write(_butemp);                                  \
+    }
 
 //===================================================================
 // Extending sizes
@@ -955,8 +956,8 @@ static inline WDataOutP VL_EXTENDS_WW(int obits, int lbits, WDataOutP owp, WData
 // REDUCTION OPERATORS
 
 // EMIT_RULE: VL_REDAND:  oclean=clean; lclean==clean; obits=1;
-#define VL_REDAND_II(obits,lbits,lhs) (lhs == VL_MASK_I(lbits))
-#define VL_REDAND_IQ(obits,lbits,lhs) (lhs == VL_MASK_Q(lbits))
+#define VL_REDAND_II(obits,lbits,lhs) ((lhs) == VL_MASK_I(lbits))
+#define VL_REDAND_IQ(obits,lbits,lhs) ((lhs) == VL_MASK_Q(lbits))
 static inline IData VL_REDAND_IW(int, int lbits, WDataInP lwp) VL_MT_SAFE {
     int words = VL_WORDS_I(lbits);
     IData combine=lwp[0];
@@ -966,8 +967,8 @@ static inline IData VL_REDAND_IW(int, int lbits, WDataInP lwp) VL_MT_SAFE {
 }
 
 // EMIT_RULE: VL_REDOR:  oclean=clean; lclean==clean; obits=1;
-#define VL_REDOR_I(lhs) (lhs!=0)
-#define VL_REDOR_Q(lhs) (lhs!=0)
+#define VL_REDOR_I(lhs) ((lhs)!=0)
+#define VL_REDOR_Q(lhs) ((lhs)!=0)
 static inline IData VL_REDOR_W(int words, WDataInP lwp) VL_MT_SAFE {
     IData equal=0;
     for (int i=0; i < words; ++i) equal |= lwp[i];
@@ -1188,7 +1189,7 @@ static inline int _VL_CMP_W(int words, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
 	if (lwp[i] > rwp[i]) return 1;
 	if (lwp[i] < rwp[i]) return -1;
     }
-    return(0); // ==
+    return(0);  // ==
 }
 
 #define VL_LTS_IWW(obits,lbits,rbbits,lwp,rwp)		(_VL_CMPS_W(lbits,lwp,rwp)<0)
@@ -1199,8 +1200,8 @@ static inline int _VL_CMP_W(int words, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
 static inline IData VL_GTS_III(int, int lbits, int, IData lhs, IData rhs) VL_PURE {
     // For lbits==32, this becomes just a single instruction, otherwise ~5.
     // GCC 3.3.4 sign extension bugs on AMD64 architecture force us to use quad logic
-    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs); //Q for gcc
-    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs); //Q for gcc
+    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs);  // Q for gcc
+    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs);  // Q for gcc
     return lhs_signed > rhs_signed;
 }
 static inline IData VL_GTS_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PURE {
@@ -1210,8 +1211,8 @@ static inline IData VL_GTS_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PUR
 }
 
 static inline IData VL_GTES_III(int, int lbits, int, IData lhs, IData rhs) VL_PURE {
-    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs); //Q for gcc
-    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs); //Q for gcc
+    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs);  // Q for gcc
+    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs);  // Q for gcc
     return lhs_signed >= rhs_signed;
 }
 static inline IData VL_GTES_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PURE {
@@ -1221,8 +1222,8 @@ static inline IData VL_GTES_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PU
 }
 
 static inline IData VL_LTS_III(int, int lbits, int, IData lhs, IData rhs) VL_PURE {
-    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs); //Q for gcc
-    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs); //Q for gcc
+    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs);  // Q for gcc
+    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs);  // Q for gcc
     return lhs_signed < rhs_signed;
 }
 static inline IData VL_LTS_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PURE {
@@ -1232,8 +1233,8 @@ static inline IData VL_LTS_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PUR
 }
 
 static inline IData VL_LTES_III(int, int lbits, int, IData lhs, IData rhs) VL_PURE {
-    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs); //Q for gcc
-    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs); //Q for gcc
+    vlsint64_t lhs_signed = VL_EXTENDS_QQ(64, lbits, lhs);  // Q for gcc
+    vlsint64_t rhs_signed = VL_EXTENDS_QQ(64, lbits, rhs);  // Q for gcc
     return lhs_signed <= rhs_signed;
 }
 static inline IData VL_LTES_IQQ(int, int lbits, int, QData lhs, QData rhs) VL_PURE {
@@ -1248,13 +1249,13 @@ static inline int _VL_CMPS_W(int lbits, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
     // We need to flip sense if negative comparison
     IData lsign = VL_SIGN_I(lbits,lwp[i]);
     IData rsign = VL_SIGN_I(lbits,rwp[i]);
-    if (!lsign && rsign) return  1; // + > -
-    if (lsign && !rsign) return -1; // - < +
+    if (!lsign && rsign) return  1;  // + > -
+    if (lsign && !rsign) return -1;  // - < +
     for (; i>=0; --i) {
-	if (lwp[i] > rwp[i]) return 1;
-	if (lwp[i] < rwp[i]) return -1;
+        if (lwp[i] > rwp[i]) return 1;
+        if (lwp[i] < rwp[i]) return -1;
     }
-    return(0); // ==
+    return(0);  // ==
 }
 
 //=========================================================================
@@ -1338,26 +1339,26 @@ static inline QData VL_MULS_QQQ(int,int lbits,int, QData lhs,QData rhs) VL_PURE
 static inline WDataOutP VL_MULS_WWW(int,int lbits,int, WDataOutP owp,WDataInP lwp,WDataInP rwp) VL_MT_SAFE {
     int words = VL_WORDS_I(lbits);
     // cppcheck-suppress variableScope
-    WData lwstore[VL_MULS_MAX_WORDS]; // Fixed size, as MSVC++ doesn't allow [words] here
+    WData lwstore[VL_MULS_MAX_WORDS];  // Fixed size, as MSVC++ doesn't allow [words] here
     // cppcheck-suppress variableScope
     WData rwstore[VL_MULS_MAX_WORDS];
     WDataInP lwusp = lwp;
     WDataInP rwusp = rwp;
     IData lneg = VL_SIGN_I(lbits,lwp[words-1]);
-    if (lneg) { // Negate lhs
-	lwusp = lwstore;
-	VL_NEGATE_W(words, lwstore, lwp);
-	lwstore[words-1] &= VL_MASK_I(lbits);  // Clean it
+    if (lneg) {  // Negate lhs
+        lwusp = lwstore;
+        VL_NEGATE_W(words, lwstore, lwp);
+        lwstore[words-1] &= VL_MASK_I(lbits);  // Clean it
     }
     IData rneg = VL_SIGN_I(lbits,rwp[words-1]);
-    if (rneg) { // Negate rhs
-	rwusp = rwstore;
-	VL_NEGATE_W(words, rwstore, rwp);
-	rwstore[words-1] &= VL_MASK_I(lbits);  // Clean it
+    if (rneg) {  // Negate rhs
+        rwusp = rwstore;
+        VL_NEGATE_W(words, rwstore, rwp);
+        rwstore[words-1] &= VL_MASK_I(lbits);  // Clean it
     }
     VL_MUL_W(words,owp,lwusp,rwusp);
     owp[words-1] &= VL_MASK_I(lbits);  // Clean.  Note it's ok for the multiply to overflow into the sign bit
-    if ((lneg ^ rneg) & 1) {      // Negate output  (not using NEGATE, as owp==lwp)
+    if ((lneg ^ rneg) & 1) {  // Negate output (not using NEGATE, as owp==lwp)
 	QData carry = 0;
 	for (int i=0; i<words; ++i) {
 	    carry = carry + static_cast<QData>(static_cast<IData>(~owp[i]));
@@ -1401,7 +1402,7 @@ static inline WDataOutP VL_DIVS_WWW(int lbits, WDataOutP owp,WDataInP lwp,WDataI
     IData lsign = VL_SIGN_I(lbits,lwp[words-1]);
     IData rsign = VL_SIGN_I(lbits,rwp[words-1]);
     // cppcheck-suppress variableScope
-    WData lwstore[VL_MULS_MAX_WORDS]; // Fixed size, as MSVC++ doesn't allow [words] here
+    WData lwstore[VL_MULS_MAX_WORDS];  // Fixed size, as MSVC++ doesn't allow [words] here
     // cppcheck-suppress variableScope
     WData rwstore[VL_MULS_MAX_WORDS];
     WDataInP ltup = lwp;
@@ -1422,7 +1423,7 @@ static inline WDataOutP VL_MODDIVS_WWW(int lbits, WDataOutP owp,WDataInP lwp,WDa
     IData lsign = VL_SIGN_I(lbits,lwp[words-1]);
     IData rsign = VL_SIGN_I(lbits,rwp[words-1]);
     // cppcheck-suppress variableScope
-    WData lwstore[VL_MULS_MAX_WORDS]; // Fixed size, as MSVC++ doesn't allow [words] here
+    WData lwstore[VL_MULS_MAX_WORDS];  // Fixed size, as MSVC++ doesn't allow [words] here
     // cppcheck-suppress variableScope
     WData rwstore[VL_MULS_MAX_WORDS];
     WDataInP ltup = lwp;
@@ -1485,12 +1486,12 @@ static inline IData VL_POWSS_III(int obits, int, int rbits,
                                  IData lhs, IData rhs, bool lsign, bool rsign) VL_MT_SAFE {
     if (VL_UNLIKELY(rhs==0)) return 1;
     if (rsign && VL_SIGN_I(rbits, rhs)) {
-	if (lhs==0) return 0;	// "X"
-	else if (lhs==1) return 1;
-	else if (lsign && lhs==VL_MASK_I(obits)) {  // -1
-	    if (rhs & 1) return VL_MASK_I(obits);  // -1^odd=-1
-	    else return 1; // -1^even=1
-	}
+        if (lhs==0) return 0;  // "X"
+        else if (lhs==1) return 1;
+        else if (lsign && lhs==VL_MASK_I(obits)) {  // -1
+            if (rhs & 1) return VL_MASK_I(obits);  // -1^odd=-1
+            else return 1;  // -1^even=1
+        }
 	return 0;
     }
     return VL_POW_III(obits, rbits, rbits, lhs, rhs);
@@ -1499,12 +1500,12 @@ static inline QData VL_POWSS_QQQ(int obits, int, int rbits,
                                  QData lhs, QData rhs, bool lsign, bool rsign) VL_MT_SAFE {
     if (VL_UNLIKELY(rhs==0)) return 1;
     if (rsign && VL_SIGN_I(rbits, rhs)) {
-	if (lhs==0) return 0;	// "X"
-	else if (lhs==1) return 1;
-	else if (lsign && lhs==VL_MASK_I(obits)) {  // -1
-	    if (rhs & 1) return VL_MASK_I(obits);  // -1^odd=-1
-	    else return 1; // -1^even=1
-	}
+        if (lhs==0) return 0;  // "X"
+        else if (lhs==1) return 1;
+        else if (lsign && lhs==VL_MASK_I(obits)) {  // -1
+            if (rhs & 1) return VL_MASK_I(obits);  // -1^odd=-1
+            else return 1;  // -1^even=1
+        }
 	return 0;
     }
     return VL_POW_QQQ(obits, rbits, rbits, lhs, rhs);
@@ -1546,9 +1547,9 @@ static inline void _VL_INSERT_WI(int, WDataOutP owp, IData ld, int hbit, int lbi
     }
     else {
 	int hword = VL_BITWORD_I(hbit);
-	int lword = VL_BITWORD_I(lbit);
-	if (hword==lword) {	// know < 32 bits because above checks it
-	    IData insmask = (VL_MASK_I(hoffset-loffset+1))<<loffset;
+        int lword = VL_BITWORD_I(lbit);
+        if (hword==lword) {  // know < 32 bits because above checks it
+            IData insmask = (VL_MASK_I(hoffset-loffset+1))<<loffset;
 	    owp[lword] = (owp[lword] & ~insmask) | ((ld<<loffset) & insmask);
 	} else {
 	    IData hinsmask = (VL_MASK_I(hoffset-0+1))<<0;
@@ -1577,9 +1578,9 @@ static inline void _VL_INSERT_WW(int, WDataOutP owp, WDataInP lwp, int hbit, int
 	// Non-32bit, but nicely aligned, so stuff all but the last word
 	for (int i=0; i<(words-1); ++i) {
 	    owp[lword+i] = lwp[i];
-	}
-	IData hinsmask = (VL_MASK_I(hoffset-0+1)); // Know it's not a full word as above fast case handled it
-	owp[lword+words-1] = (owp[words+lword-1] & ~hinsmask) | (lwp[words-1] & hinsmask);
+        }
+        IData hinsmask = (VL_MASK_I(hoffset-0+1));  // Know it's not a full word as above fast case handled it
+        owp[lword+words-1] = (owp[words+lword-1] & ~hinsmask) | (lwp[words-1] & hinsmask);
     }
     else {
 	IData hinsmask = (VL_MASK_I(hoffset-0+1))<<0;
@@ -1685,20 +1686,24 @@ static inline IData VL_STREAML_FAST_III(int, int lbits, int, IData ld, IData rd_
     //   ret = 10324---
     IData ret = ld;
     if (rd_log2) {
-	vluint32_t lbitsFloor = lbits & ~VL_MASK_I(rd_log2); // max multiple of rd <= lbits
-	vluint32_t lbitsRem = lbits - lbitsFloor; // number of bits in most-sig slice (MSS)
-	IData msbMask = VL_MASK_I(lbitsRem) << lbitsFloor; // mask to sel only bits in MSS
-	ret = (ret & ~msbMask) | ((ret & msbMask) << ((VL_UL(1) << rd_log2) - lbitsRem));
+        vluint32_t lbitsFloor = lbits & ~VL_MASK_I(rd_log2);  // max multiple of rd <= lbits
+        vluint32_t lbitsRem = lbits - lbitsFloor;  // number of bits in most-sig slice (MSS)
+        IData msbMask = VL_MASK_I(lbitsRem) << lbitsFloor;  // mask to sel only bits in MSS
+        ret = (ret & ~msbMask) | ((ret & msbMask) << ((VL_UL(1) << rd_log2) - lbitsRem));
     }
     switch (rd_log2) {
-	case 0:
-	    ret = ((ret >> 1) & VL_UL(0x55555555)) | ((ret & VL_UL(0x55555555)) << 1);    // FALLTHRU
-	case 1:
-	    ret = ((ret >> 2) & VL_UL(0x33333333)) | ((ret & VL_UL(0x33333333)) << 2);    // FALLTHRU
-	case 2:
-	    ret = ((ret >> 4) & VL_UL(0x0f0f0f0f)) | ((ret & VL_UL(0x0f0f0f0f)) << 4);    // FALLTHRU
-	case 3:
-	    ret = ((ret >> 8) & VL_UL(0x00ff00ff)) | ((ret & VL_UL(0x00ff00ff)) << 8);    // FALLTHRU
+        case 0:
+            ret = ((ret >> 1) & VL_UL(0x55555555))
+                | ((ret & VL_UL(0x55555555)) << 1);  // FALLTHRU
+        case 1:
+            ret = ((ret >> 2) & VL_UL(0x33333333))
+                | ((ret & VL_UL(0x33333333)) << 2);  // FALLTHRU
+        case 2:
+            ret = ((ret >> 4) & VL_UL(0x0f0f0f0f))
+                | ((ret & VL_UL(0x0f0f0f0f)) << 4);  // FALLTHRU
+        case 3:
+            ret = ((ret >> 8) & VL_UL(0x00ff00ff))
+                | ((ret & VL_UL(0x00ff00ff)) << 8);  // FALLTHRU
 	case 4:
 	    ret = ((ret >> 16) | (ret << 16));
     }
@@ -1892,17 +1897,17 @@ static inline WDataOutP VL_SHIFTL_WWI(int obits,int,int,WDataOutP owp,WDataInP l
 static inline WDataOutP VL_SHIFTL_WWW(int obits, int lbits, int rbits,
                                       WDataOutP owp, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    return VL_ZERO_W(obits, owp);
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            return VL_ZERO_W(obits, owp);
+        }
     }
     return VL_SHIFTL_WWI(obits,lbits,32,owp,lwp,rwp[0]);
 }
 static inline IData VL_SHIFTL_IIW(int obits,int,int rbits,IData lhs, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    return 0;
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            return 0;
+        }
     }
     return VL_CLEAN_II(obits,obits,lhs<<rwp[0]);
 }
@@ -1939,17 +1944,17 @@ static inline WDataOutP VL_SHIFTR_WWI(int obits, int, int,
 static inline WDataOutP VL_SHIFTR_WWW(int obits, int lbits, int rbits,
                                       WDataOutP owp, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    return VL_ZERO_W(obits, owp);
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            return VL_ZERO_W(obits, owp);
+        }
     }
     return VL_SHIFTR_WWI(obits,lbits,32,owp,lwp,rwp[0]);
 }
 static inline IData VL_SHIFTR_IIW(int obits,int,int rbits,IData lhs, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    return 0;
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            return 0;
+        }
     }
     return VL_CLEAN_II(obits,obits,lhs>>rwp[0]);
 }
@@ -1960,8 +1965,8 @@ static inline IData VL_SHIFTRS_III(int obits, int lbits, int, IData lhs, IData r
     // IEEE says signed if output signed, but bit position from lbits;
     // must use lbits for sign; lbits might != obits,
     // an EXTEND(SHIFTRS(...)) can became a SHIFTRS(...) within same 32/64 bit word length
-    IData sign    = -(lhs >> (lbits-1)); // ffff_ffff if negative
-    IData signext = ~(VL_MASK_I(lbits) >> rhs);   // One with bits where we've shifted "past"
+    IData sign    = -(lhs >> (lbits-1));  // ffff_ffff if negative
+    IData signext = ~(VL_MASK_I(lbits) >> rhs);  // One with bits where we've shifted "past"
     return (lhs >> rhs) | (sign & VL_CLEAN_II(obits,obits,signext));
 }
 static inline QData VL_SHIFTRS_QQI(int obits, int lbits, int, QData lhs, IData rhs) VL_PURE {
@@ -2009,9 +2014,9 @@ static inline WDataOutP VL_SHIFTRS_WWI(int obits, int lbits, int,
 static inline WDataOutP VL_SHIFTRS_WWW(int obits, int lbits, int rbits,
                                        WDataOutP owp, WDataInP lwp, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    int lmsw = VL_WORDS_I(obits)-1;
-	    IData sign = VL_SIGNONES_I(lbits,lwp[lmsw]);
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            int lmsw = VL_WORDS_I(obits)-1;
+            IData sign = VL_SIGNONES_I(lbits,lwp[lmsw]);
 	    for (int j=0; j <= lmsw; ++j) owp[j] = sign;
 	    owp[lmsw] &= VL_MASK_I(lbits);
 	    return owp;
@@ -2022,20 +2027,20 @@ static inline WDataOutP VL_SHIFTRS_WWW(int obits, int lbits, int rbits,
 static inline IData VL_SHIFTRS_IIW(int obits, int lbits, int rbits,
                                    IData lhs, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    IData sign    = -(lhs >> (lbits-1)); // ffff_ffff if negative
-	    return VL_CLEAN_II(obits,obits,sign);
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            IData sign = -(lhs >> (lbits-1));  // ffff_ffff if negative
+            return VL_CLEAN_II(obits,obits,sign);
+        }
     }
     return VL_SHIFTRS_III(obits,lbits,32,lhs,rwp[0]);
 }
 static inline QData VL_SHIFTRS_QQW(int obits, int lbits, int rbits,
                                    QData lhs, WDataInP rwp) VL_MT_SAFE {
     for (int i=1; i < VL_WORDS_I(rbits); ++i) {
-	if (VL_UNLIKELY(rwp[i])) { // Huge shift 1>>32 or more
-	    QData sign    = -(lhs >> (lbits-1)); // ffff_ffff if negative
-	    return VL_CLEAN_QQ(obits,obits,sign);
-	}
+        if (VL_UNLIKELY(rwp[i])) {  // Huge shift 1>>32 or more
+            QData sign = -(lhs >> (lbits-1));  // ffff_ffff if negative
+            return VL_CLEAN_QQ(obits,obits,sign);
+        }
     }
     return VL_SHIFTRS_QQI(obits,lbits,32,lhs,rwp[0]);
 }
@@ -2060,8 +2065,8 @@ static inline QData VL_SHIFTRS_QQQ(int obits,int lbits,int rbits,QData lhs, QDat
 static inline IData VL_BITSEL_IWII(int, int lbits, int, int, WDataInP lwp, IData rd) VL_MT_SAFE {
     int word = VL_BITWORD_I(rd);
     if (VL_UNLIKELY(rd > static_cast<IData>(lbits))) {
-	return ~0; // Spec says you can go outside the range of a array.  Don't coredump if so.
-	// We return all 1's as that's more likely to find bugs (?) than 0's.
+        return ~0;  // Spec says you can go outside the range of a array.  Don't coredump if so.
+        // We return all 1's as that's more likely to find bugs (?) than 0's.
     } else {
 	return (lwp[word]>>VL_BITBIT_I(rd));
     }
@@ -2077,7 +2082,7 @@ static inline IData VL_SEL_IWII(int, int lbits, int, int,
                                 WDataInP lwp, IData lsb, IData width) VL_MT_SAFE {
     int msb = lsb+width-1;
     if (VL_UNLIKELY(msb>lbits)) {
-	return ~0; // Spec says you can go outside the range of a array.  Don't coredump if so.
+        return ~0;  // Spec says you can go outside the range of a array.  Don't coredump if so.
     } else if (VL_BITWORD_I(msb)==VL_BITWORD_I(static_cast<int>(lsb))) {
         return VL_BITRSHIFT_W(lwp, lsb);
     } else {
@@ -2092,7 +2097,7 @@ static inline QData VL_SEL_QWII(int, int lbits, int, int,
                                 WDataInP lwp, IData lsb, IData width) VL_MT_SAFE {
     int msb = lsb+width-1;
     if (VL_UNLIKELY(msb>lbits)) {
-	return ~0; // Spec says you can go outside the range of a array.  Don't coredump if so.
+        return ~0;  // Spec says you can go outside the range of a array.  Don't coredump if so.
     } else if (VL_BITWORD_I(msb)==VL_BITWORD_I(static_cast<int>(lsb))) {
         return VL_BITRSHIFT_W(lwp, lsb);
     } else if (VL_BITWORD_I(msb)==1+VL_BITWORD_I(static_cast<int>(lsb))) {
@@ -2114,9 +2119,9 @@ static inline WDataOutP VL_SEL_WWII(int obits, int lbits, int, int,
                                     WDataOutP owp, WDataInP lwp, IData lsb, IData width) VL_MT_SAFE {
     int msb = lsb+width-1;
     int word_shift = VL_BITWORD_I(lsb);
-    if (VL_UNLIKELY(msb>lbits)) { // Outside bounds,
-	for (int i=0; i<VL_WORDS_I(obits)-1; ++i) owp[i] = ~0;
-	owp[VL_WORDS_I(obits)-1] = VL_MASK_I(obits);
+    if (VL_UNLIKELY(msb>lbits)) {  // Outside bounds,
+        for (int i=0; i<VL_WORDS_I(obits)-1; ++i) owp[i] = ~0;
+        owp[VL_WORDS_I(obits)-1] = VL_MASK_I(obits);
     } else if (VL_BITBIT_I(lsb)==0) {
 	// Just a word extract
 	for (int i=0; i<VL_WORDS_I(obits); ++i) owp[i] = lwp[i+word_shift];
@@ -2284,4 +2289,4 @@ static inline void VL_CONSTLO_W_8X(int lsb, WDataOutP obase,
 
 //======================================================================
 
-#endif /*_VERILATED_H_*/
+#endif  // Guard
